@@ -134,13 +134,14 @@ function(id=1, centre.xy=NULL, calccentre=TRUE, weighted=FALSE, weights=NULL, po
 	  print(result.box)
     } # END IF
         
-    # RETURN LIST WITH FIVE ELEMENTS:
+    # RETURN LIST WITH SIX ELEMENTS:
     # ELEMENT 1: A TYPE INDICATOR (BOX, SDD, OR SDE)
     # ELEMENT 2: DATE AND TIME THAT FUNCTION WAS RUN
-    # ELEMENT 3: boxloc IS A DATAFRAME REQUIRED FOR THE CONVERT.TO.SHAPEFILE FUNCTION
-    # ELEMENT 2: r.BOX IS A LIST OBJECT REQUIRED FOR PLOTTING
-    # ELEMENT 3: boxatt IS THE SD BOX ATTRIBUTES IN A DATA FRAME
-    returnlist <- list("TYPE"="BOX", "DATE"=date(), "LOCATIONS"=boxloc, "FORPLOTTING"=r.BOX, "ATTRIBUTES"=result.box)
+    # ELEMENT 3: UNIQUE ID FOR DATASET (PASSED AS ARGUMENT TO THIS FUNCTION)
+    # ELEMENT 4: boxloc IS A DATAFRAME REQUIRED FOR THE CONVERT.TO.SHAPEFILE FUNCTION
+    # ELEMENT 5: r.BOX IS A LIST OBJECT REQUIRED FOR PLOTTING
+    # ELEMENT 6: boxatt IS THE SD BOX ATTRIBUTES IN A DATA FRAME
+    returnlist <- list("TYPE"="BOX", "DATE"=date(), "ID"=id, "LOCATIONS"=boxloc, "FORPLOTTING"=r.BOX, "ATTRIBUTES"=result.box)
     return(returnlist)
   }
   else {
